﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml.Serialization;

namespace SqlBI.DtExec.Classes {
    [XmlRootAttribute ("Package")]
    public class PackageInformation {
        private string name = "";
        private string path = "";
        private bool execute = false;
        private int order = 0;
        private LoggingOptions logging = null;
        private EventsOption events = null;
        private bool logToConsole = false;
        private bool eventsToConsole = false;
        private string logToFileName = "";
        private string password = "";
        private string eventsToFileName = "";
        private string endPointToUse;
        private List<PackageConfiguration> configurations = new List<PackageConfiguration> ();

        /// <summary>
        /// 
        ///     Contains the list of all the configurations of the package
        /// 
        /// </summary>
        public List<PackageConfiguration> Configurations {
            get { return configurations; }
            set { configurations = value; }
        }

        /// <summary>
        /// 
        ///     The name of the WCF endpoint to use to open the communication
        ///     channel for this package
        /// 
        /// </summary>
        public string EndPointToUse {
            get { return endPointToUse; }
            set { endPointToUse = value; }
        }

        /// <summary>
        /// 
        ///     True if we want to send the log to the console
        ///     
        /// </summary>
        public bool LogToConsole {
            get { return logToConsole; }
            set { logToConsole = value; }
        }

        /// <summary>
        /// 
        ///     True if we want to send the events to the console
        ///     
        /// </summary>
        public bool EventsToConsole {
            get { return eventsToConsole; }
            set { eventsToConsole = value; }
        }

        /// <summary>
        /// 
        ///     Path of the filename where to write logs
        /// 
        /// </summary>
        public string LogToFileName {
            get { return logToFileName; }
            set { logToFileName = value; }
        }

        /// <summary>
        /// 
        ///     Path of the filename where to write events
        /// 
        /// </summary>
        public string EventsToFileName {
            get { return eventsToFileName; }
            set { eventsToFileName = value; }
        }

        /// <summary>
        /// 
        ///     Options for logging
        /// 
        /// </summary>
        public LoggingOptions Logging {
            get { return logging; }
            set { logging = value; }
        }

        /// <summary>
        /// 
        ///     Options for the event logging
        /// 
        /// </summary>
        public EventsOption Events {
            get { return events; }
            set { events = value; }
        }

        /// <summary>
        /// 
        ///     Name of the package
        /// 
        /// </summary>
        public string Name {
            get { return name; }
            set { name = value; }
        }

        /// <summary>
        ///     
        ///     Optional password for the package
        /// 
        /// </summary>
        public string Password {
            get { return password; }
            set { password = value; }
        }

        /// <summary>
        /// 
        ///     Path of the package, if is is stored in the file system
        /// 
        /// </summary>
        public string Path {
            get { return path; }
            set { path = value; }
        }

        /// <summary>
        /// 
        ///     flag that tells us if the package needs to be executed
        /// 
        /// </summary>
        public bool Execute {
            get { return execute; }
            set { execute = value; }
        }

        /// <summary>
        /// 
        ///     Order of execution. All packages with the same order
        ///     will be executed in separate threads in parallel
        /// 
        /// </summary>
        public int Order {
            get { return order; }
            set { order = value; }
        }
    }
    /// <summary>
    /// 
    ///     Contains the information about what to send to the client
    ///     from the log pipeline
    /// 
    /// </summary>
    [XmlRootAttribute ("Logging")]
    public class LoggingOptions {
        private bool logName = false;
        private bool logComputer = false;
        private bool logOperator = false;
        private bool logSourcename = false;
        private bool logSourceGUID = false;
        private bool logExecutionGUID = false;
        private bool logMessage = false;
        private bool logStartAndEndTime = false;

        public bool LogName {
            get { return logName; }
            set { logName = value; }
        }

        public bool LogComputer {
            get { return logComputer; }
            set { logComputer = value; }
        }

        public bool LogOperator {
            get { return logOperator; }
            set { logOperator = value; }
        }

        public bool LogSourcename {
            get { return logSourcename; }
            set { logSourcename = value; }
        }

        public bool LogSourceGUID {
            get { return logSourceGUID; }
            set { logSourceGUID = value; }
        }

        public bool LogExecutionGUID {
            get { return logExecutionGUID; }
            set { logExecutionGUID = value; }
        }

        public bool LogMessage {
            get { return logMessage; }
            set { logMessage = value; }
        }

        public bool LogStartAndEndTime {
            get { return logStartAndEndTime; }
            set { logStartAndEndTime = value; }
        }
    }

    /// <summary>
    /// 
    ///     Contains information about what to send to the client
    ///     from the event pipeline
    /// 
    /// </summary>
    [XmlRootAttribute ("Events")]
    public class EventsOption {
        private bool reportPreValidate = false;
        private bool reportPostValidate = false;
        private bool reportPreExecute = false;
        private bool reportPostExecute = false;
        private bool reportErrors = false;
        private bool reportVariableValueChanged = false;
        private bool reportCustomEvents = false;
        private bool reportTaskFailed = false;
        private bool reportInformation = false;
        private bool reportWarnings = false;
        private bool reportProgress = false;

        public bool ReportProgress {
            get { return reportProgress; }
            set { reportProgress = value; }
        }

        public bool ReportPreValidate {
            get { return reportPreValidate; }
            set { reportPreValidate = value; }
        }

        public bool ReportPostValidate {
            get { return reportPostValidate; }
            set { reportPostValidate = value; }
        }

        public bool ReportPreExecute {
            get { return reportPreExecute; }
            set { reportPreExecute = value; }
        }

        public bool ReportPostExecute {
            get { return reportPostExecute; }
            set { reportPostExecute = value; }
        }

        public bool ReportErrors {
            get { return reportErrors; }
            set { reportErrors = value; }
        }

        public bool ReportVariableValueChanged {
            get { return reportVariableValueChanged; }
            set { reportVariableValueChanged = value; }
        }

        public bool ReportCustomEvents {
            get { return reportCustomEvents; }
            set { reportCustomEvents = value; }
        }

        public bool ReportTaskFailed {
            get { return reportTaskFailed; }
            set { reportTaskFailed = value; }
        }

        public bool ReportInformation {
            get { return reportInformation; }
            set { reportInformation = value; }
        }

        public bool ReportWarnings {
            get { return reportWarnings; }
            set { reportWarnings = value; }
        }
    }

    /// <summary>
    /// 
    ///     Configuration contains a single configuration for the package
    ///     consisting in a name and a string value.
    /// 
    /// </summary>
    public class PackageConfiguration {
        string name;
        string value;

        public string Name {
            get { return name; }
            set { name = value; }
        }

        public string Value {
            get { return this.value; }
            set { this.value = value; }
        }
    }
}
