﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ServiceModel;
using SqlBI.DtExec.Classes;
using SqlBI.DtExec.Contracts;

namespace SqlBI.DtExec.ClientAgent {

    /// <summary>
    /// 
    ///     Callback is handled in this class, which makes it easier to 
    ///     handle it from the client side
    /// 
    /// </summary>
    /// <param name="percentage"></param>
    public delegate void OnLogMessage (LogItem logItem);
    [CallbackBehavior (ConcurrencyMode = ConcurrencyMode.Reentrant, UseSynchronizationContext = false)]
    class CallbackListener : ILogCallback {
        internal OnLogMessage callbackDelegate;

        public CallbackListener (OnLogMessage parCallbackDelegate) {
            this.callbackDelegate = parCallbackDelegate;
        }

        public void OnLogMessage (LogItem logItem) {
            if (callbackDelegate != null) {
                callbackDelegate.Invoke (logItem);
            }
        }
    }

    /// <summary>
    /// 
    ///     ClientAgent provides an easy interface versus the WCF channel
    /// 
    /// </summary>
    public class ClientAgent {

        /// <summary>
        /// 
        ///     Executes remotely a package using the specified endPoint and the specified
        ///     callback method
        /// 
        /// </summary>
        /// <param name="package"></param>
        /// <param name="logMessage"></param>
        /// <param name="endPoint"></param>
        static public string ExecutePackage (PackageInformation package, OnLogMessage logMessage) {
            string result = "";
            try {
                CallbackListener callbackListener = new CallbackListener (logMessage);
                InstanceContext context = new InstanceContext (callbackListener);
                DuplexChannelFactory<IServiceSqlBIDtExec> factory = new DuplexChannelFactory<IServiceSqlBIDtExec> (context, package.EndPointToUse);
                try {
                    IServiceSqlBIDtExec channel = factory.CreateChannel ();
                    result = channel.RunPackage (package);
                } finally {
                    factory.Close ();
                }
            } catch (Exception e) {
                result = "Error: " + e.Message;
            }
            return result;
        }
    }
}
