﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SqlServer.Dts.Runtime;
using SqlBI.DtExec.Services;
using SqlBI.DtExec.Classes;

namespace SqlBI.DtExec.Services {
    /// <summary>
    /// 
    ///     This class receives log information from SSIS and sends them 
    ///     back to the client, after having formatted them correctly
    /// 
    /// </summary>
    public class LoggingHandler : IDTSLogging {

        /// <summary>
        /// 
        ///     Contains the caller class, used to invoke the callback
        /// 
        /// </summary>
        private ServiceSqlBIDtExec Caller = null;
        private SqlBI.DtExec.Classes.LoggingOptions Logging;

        /// <summary>
        /// 
        ///     Constructor of the logging class
        /// 
        /// </summary>
        /// <param name="caller"></param>
        public LoggingHandler (ServiceSqlBIDtExec caller, SqlBI.DtExec.Classes.LoggingOptions logging) {
            Caller = caller;
            Logging = logging;
        }

        /// <summary>
        /// 
        ///     Needed for the IDTSEvents interface
        /// 
        /// </summary>
        public bool Enabled {
            get { return true; }
        }

        /// <summary>
        /// 
        ///     Needed for the IDTSEvents interface
        /// 
        /// </summary>
        /// <param name="eventNames"></param>
        /// <returns></returns>
        public bool[] GetFilterStatus (ref string[] eventNames) {
            bool[] result = new bool[eventNames.Length];
            for (int i = 0; i < eventNames.Length; i++) {

                //Caller.SendBackMessage (eventNames[i]);

                result[i] = false;
            }
            return result;
        }

        /// <summary>
        /// 
        ///     Needed for the IDTSEvents interface
        ///     
        ///     This method is invoked at each log
        /// 
        /// </summary>
        /// <param name="eventName"></param>
        /// <param name="computerName"></param>
        /// <param name="operatorName"></param>
        /// <param name="sourceName"></param>
        /// <param name="sourceGuid"></param>
        /// <param name="executionGuid"></param>
        /// <param name="messageText"></param>
        /// <param name="startTime"></param>
        /// <param name="endTime"></param>
        /// <param name="dataCode"></param>
        /// <param name="dataBytes"></param>
        public void Log (string eventName, string computerName, string operatorName, string sourceName, string sourceGuid, string executionGuid, string messageText, DateTime startTime, DateTime endTime, int dataCode, ref byte[] dataBytes) {
            string resultMessage = "";
            if (Logging.LogStartAndEndTime) {
                resultMessage += startTime.ToShortTimeString () + "\t";
                resultMessage += endTime.ToShortTimeString () + "\t";
            }
            if (Logging.LogComputer) {
                resultMessage += computerName + "\t";
            }
            if (Logging.LogOperator) {
                resultMessage += operatorName + "\t";
            }
            if (Logging.LogSourcename) {
                resultMessage += sourceName + "\t";
            }
            if (Logging.LogSourceGUID) {
                resultMessage += sourceGuid + "\t";
            }
            if (Logging.LogExecutionGUID) {
                resultMessage += executionGuid + "\t";
            }
            if (Logging.LogMessage) {
                resultMessage += messageText + "\t";
            }
            if (resultMessage != "") {
                Caller.SendBackMessage (LogType.Log, resultMessage);
            }
        }
    }
}
